@@ -104,3 +104,18 @@ class LackOfNecessaryPlugin(Signal):
     def dispatch(self, plugin_tye):
         super().dispatch(plugin_tye)
 
+
+@singleton
+class ExceptionSignal(Signal):
+    """
+    出现异常时的信号
+    """
+    def dispatch(self, error_code: int, error_msg: str):
+        super().dispatch(error_code, error_msg)
+
+    # def on(self, handler):
+    #     raise Exception("you should use on_")
+
+    # def on_exception(self, error_code, caller):
+    #     pass
+
